@@ -12,12 +12,21 @@ from datetime import datetime
 from typing import Optional
 from . import util
 
+ALL_AUTHORS = "consider_all_authors"
+
 
 class Config:
-    def __init__(self, config_dict):
-        self._authors_to_index = [
-            util.get_shortform(a) for a in config_dict.pop("authors_to_be_indexed", [])
-        ]
+    def __init__(self, config_dict, cmdline_params):
+        if cmdline_params.create_single_page:
+            # ignore authors to be indexed in config file
+            self._authors_to_index = []
+            config_dict.pop("authors_to_be_indexed", None)
+        elif "authors_to_be_indexed" in config_dict:
+            self._authors_to_index = [
+                util.get_shortform(a) for a in config_dict.pop("authors_to_be_indexed")
+            ]
+        else:
+            self._authors_to_index = ALL_AUTHORS
 
         self._tail = config_dict.pop("tail", "")
 
@@ -26,7 +35,7 @@ class Config:
 
     def index_author(self, author):
         return (
-            not self._authors_to_index
+            self._authors_to_index == ALL_AUTHORS
             or util.get_shortform(author) in self._authors_to_index
         )
 
@@ -38,9 +47,8 @@ class Config:
         return datetime.now().strftime(r"%a %b %d %H:%M:%S %Y")
 
 
-def parse(config_file: Optional[str]) -> Config:
+def parse(config_file: Optional[str], args) -> Config:
     if config_file is None:
-        return Config({})
-
+        return Config({}, args)
     with open(config_file) as inp:
-        return Config(yaml.safe_load(inp))
+        return Config(yaml.safe_load(inp), args)
