@@ -167,7 +167,7 @@ def authors_to_html(entry, config: Config):
             authors_html = ""
     if not authors_html:
         return ""
-    return f'<span class="author-list">\n{indent(1, authors_html)}\n</span>'
+    return f'<span class="author-list">{authors_html}</span>'
 
 
 def editors_to_html(entry, config: Config):
@@ -180,7 +180,7 @@ def editors_to_html(entry, config: Config):
         editors_html = ""
     if not editors_html:
         return ""
-    return f'<span class="editor-list">\n{indent(1, editors_html)}\n</span>'
+    return f'<span class="editor-list">{editors_html}</span>'
 
 
 def funders_to_html(entry):
@@ -219,7 +219,7 @@ def _get_list_of_names(
     if len(ls) > 2:
         ls = [delimiter_intermediate.join(ls[:-1]), ls[-1]]
         if not delimiter_last.startswith(","):
-            delimiter_last = ", " + delimiter_last
+            delimiter_last = ", " + delimiter_last.strip() + "\n"
     assert (
         len(ls) <= 2
     ), f"There shouldn't be more than two elements after joining them with delimiter_intermediate: {ls}"
@@ -253,7 +253,7 @@ def publication_venue_to_html(entry, config):
         ]
     )
     if date_html:
-        date = f'<span class="publication-date">\n{indent(1, date_html)}\n</span>'
+        date = f'<span class="publication-date">{indent(1, date_html)}</span>'
     else:
         date = ""
 
@@ -313,9 +313,7 @@ def publication_venue_to_html(entry, config):
         else:
             editors = ""
         try:
-            booktitle = (
-                f"<em class=\"booktitle\">\n{indent(1, entry['booktitle'])}\n</em>"
-            )
+            booktitle = f"<em class=\"booktitle\">{indent(1, entry['booktitle'])}</em>"
         except KeyError:
             logging.debug("No booktitle for %s", entry)
             booktitle = ""
@@ -465,23 +463,32 @@ def html_id(entry):
 
 
 def writes(
-    categorized_entries: Dict[Category, Sequence[dict]], *, config, header_title=None
-) -> Iterable[str]:
-    for category, entries in categorized_entries.items():
-        if category.link:
-            yield f'<a href="../{category.link}"><h3>{category.name}</h3></a>'
-        else:
-            yield f"<h3>{category.name}</h3>"
-        yield ""
-        yield f'<ol class="list-{header_title.lower().replace(" ", "-")}">'
-        yield ""
-        for entry in entries:
-            yield to_html(entry, config=config)
+    categorized_entries: Dict[Category, Sequence[dict]],
+    *,
+    config,
+    head=None,
+    header_title=None,
+) -> str:
+    def gen():
+        if head:
+            yield head
+        for category, entries in categorized_entries.items():
+            if category.link:
+                yield f'<a href="../{category.link}"><h3>{category.name}</h3></a>'
+            else:
+                yield f"<h3>{category.name}</h3>"
             yield ""
-        yield "</ol>"
-    tail = config.tail
-    if tail:
-        yield tail
+            yield f'<ol class="list-{header_title.lower().replace(" ", "-")}">'
+            yield ""
+            for entry in entries:
+                yield to_html(entry, config=config)
+                yield ""
+            yield "</ol>"
+        tail = config.tail
+        if tail:
+            yield tail
+
+    return "\n".join(gen())
 
 
 def write(
@@ -495,22 +502,16 @@ def write(
     output_file = Path(output_file)
     output_file.parent.mkdir(exist_ok=True, parents=True)
     with open(output_file, "w") as outp:
-        html = []
-        if head:
-            html.append(head)
-        html += [
-            f"{line}\n"
-            for line in writes(entries, config=config, header_title=header_title)
-        ]
+        html = writes(entries, config=config, head=head, header_title=header_title)
         write_html(outp, html)
 
 
-def write_html(output_obj, html_lines):
+def write_html(output_obj, html: str):
     start = f"<!-- This file was generated by pybib2web, version {__version__}: https://gitlab.com/sosy-lab/software/pybib2web/ -->"
 
     end = f'<footer id="generator">This file was generated by <a href="https://gitlab.com/sosy-lab/software/pybib2web/">pybib2web</a>, version {__version__}</footer>'
     output_obj.write(start)
-    output_obj.writelines(html_lines)
+    output_obj.write(html)
     output_obj.write(end)
 
 
@@ -630,7 +631,7 @@ def write_html_tree(entries: Sequence[dict], output_root, *, config, header_titl
             yield "</ul>"
 
     with open(output_root / "index.html", "w") as outp:
-        write_html(outp, [f"{line}\n" for line in index_page(header_title)])
+        write_html(outp, "\n".join(index_page(header_title)))
 
 
 def write_year_tree(entries: Sequence[dict], output_root, *, config, header_title):
@@ -793,6 +794,13 @@ def write_by_year(entries, output_file, *, config, header_title, head=None):
     write(by_year, output_file, head=head, config=config, header_title=header_title)
 
 
+def html_by_year(entries, *, config, header_title, head=None):
+    years = {Category(cat, None): es for cat, es in categories.by_year(entries).items()}
+    if head is None:
+        head = f"<h2>{header_title} by year</h2>"
+    return writes(years, config=config, head=head, header_title=header_title)
+
+
 def _keyword_to_link(keyword):
     assert keyword
     adjusted = re.sub("[()]", "", keyword.upper().replace(" ", "-"))
